Module test_runtime

Module test_runtime 

Deterministic test runtime harness helpers.

Functions

assert_no_leaked_fibers
Assert that no leaked fibers were recorded in the current test harness run.
assert_no_unclosed_scopes
Assert that no unclosed scopes were recorded in the current test harness run.
record_leaked_fiber
Internal hook for tests that need to simulate leaked fibers.
record_unclosed_scope
Internal hook for tests that need to simulate unclosed scopes.
run_test
Run an effect in deterministic test mode and return an Exit value.
run_test_with_clock
Run an effect in deterministic test mode with an explicit test clock.