pub struct RefinedBrand<A, B, E = String> { /* private fields */ }Expand description
A branded constructor that validates the inner value at runtime.
Mirrors Effect.ts Brand.refined(refine, onFailure).
Implementations
Sourceimpl<A: Clone, B, E: Clone> RefinedBrand<A, B, E>
impl<A: Clone, B, E: Clone> RefinedBrand<A, B, E>
Sourcepub fn new(refine: impl Fn(&A) -> Result<(), E> + Send + Sync + 'static) -> Self
pub fn new(refine: impl Fn(&A) -> Result<(), E> + Send + Sync + 'static) -> Self
Create a new refined brand constructor with a validation function.
refine returns Ok(()) when the value is valid, Err(e) otherwise.
Sourcepub fn try_make(&self, value: A) -> Result<Brand<A, B>, E>
pub fn try_make(&self, value: A) -> Result<Brand<A, B>, E>
Try to brand value. Returns Ok(Brand<A,B>) or Err(E).
Sourcepub fn make_option(&self, value: A) -> Option<Brand<A, B>>
pub fn make_option(&self, value: A) -> Option<Brand<A, B>>
Returns Some(Brand<A,B>) if valid, None otherwise.