Deterministic test runtime harness helpers.
Functions
- assert_
no_ leaked_ fibers - Assert that no leaked fibers were recorded in the current test harness run.
- assert_
no_ unclosed_ scopes - Assert that no unclosed scopes were recorded in the current test harness run.
- record_
leaked_ fiber - Internal hook for tests that need to simulate leaked fibers.
- record_
unclosed_ scope - Internal hook for tests that need to simulate unclosed scopes.
- run_
test - Run an effect in deterministic test mode and return an
Exitvalue. - run_
test_ with_ clock - Run an effect in deterministic test mode with an explicit test clock.